.. SPDX-FileCopyrightText: 2021-2023 Constantine Evans <qslib@mb.costi.net>
..
.. SPDX-License-Identifier: EUPL-1.2

.. _commandline:

Command-line Interface
======================

.. click:: qslib.cli:cli
   :prog: qslib
   :nested: full
